@@ -38,11 +38,9 @@ be used.
 """
 
 
-from __future__ import absolute_import
 import atexit
 import gettext
 import os
-import six
 import sys
 import proboscis
 
@@ -71,10 +69,7 @@ def add_support_for_localization():
     if os.path.exists(os.path.join(possible_topdir, 'nova', '__init__.py')):
         sys.path.insert(0, possible_topdir)
 
-    if six.PY3:
-        gettext.install('nova')
-    else:
-        gettext.install('nova', unicode=True)
+    gettext.install('nova')
 
 
 MAIN_RUNNER = None
