@@ -59,14 +59,10 @@ import heapq
 import logging
 import os
 import unittest
-import six
 import sys
 import time
 
-if six.PY2:
-    gettext.install('nova', unicode=1)
-else:
-    gettext.install('nova')
+gettext.install('nova')
 
 from nose import config
 from nose import core
