@@ -12,7 +12,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import sys
 
 from oslo_config import cfg as openstack_cfg
@@ -23,6 +22,8 @@ from trove.common import cfg
 from trove.common import debug_utils
 from trove.common.i18n import _
 from trove.guestagent import api as guest_api
+from trove.guestagent.common import operating_system
+from trove.guestagent import volume
 
 CONF = cfg.CONF
 # The guest_id opt definition must match the one in common/cfg.py
@@ -31,9 +32,18 @@ CONF.register_opts([openstack_cfg.StrOpt('guest_id', default=None,
                     openstack_cfg.StrOpt('instance_rpc_encr_key',
                                          help=('Key (OpenSSL aes_cbc) for '
                                                'instance RPC encryption.'))])
+LOG = logging.getLogger(__name__)
 
 
 def main():
+    log_levels = [
+        'docker=WARN',
+    ]
+    default_log_levels = logging.get_default_log_levels()
+    default_log_levels.extend(log_levels)
+    logging.set_defaults(default_log_levels=default_log_levels)
+    logging.register_options(CONF)
+
     cfg.parse_args(sys.argv)
     logging.setup(CONF, None)
     debug_utils.setup()
@@ -50,8 +60,25 @@ def main():
                "was not injected into the guest or not read by guestagent"))
         raise RuntimeError(msg)
 
-    # BUG(1650518): Cleanup in the Pike release
-    # make it fatal if CONF.instance_rpc_encr_key is None
+    # Create user and group for running docker container.
+    LOG.info('Creating user and group for database service')
+    uid = cfg.get_configuration_property('database_service_uid')
+    operating_system.create_user('database', uid)
+
+    # Mount device if needed.
+    # When doing rebuild, the device should be already formatted but not
+    # mounted.
+    device_path = CONF.get(CONF.datastore_manager).device_path
+    mount_point = CONF.get(CONF.datastore_manager).mount_point
+    device = volume.VolumeDevice(device_path)
+    if not device.mount_points(device_path):
+        LOG.info('Preparing the storage for %s, mount path %s',
+                 device_path, mount_point)
+        device.format()
+        device.mount(mount_point)
+        operating_system.chown(mount_point, CONF.database_service_uid,
+                               CONF.database_service_uid,
+                               recursive=True, as_root=True)
 
     # rpc module must be loaded after decision about thread monkeypatching
     # because if thread module is not monkeypatched we can't use eventlet
