@@ -410,7 +410,8 @@ instance = {
                         "additionalProperties": True,
                         "properties": {
                             "type": non_empty_string,
-                            "version": non_empty_string
+                            "version": non_empty_string,
+                            "version_number": non_empty_string
                         }
                     },
                     "nics": nics,
@@ -651,14 +652,27 @@ backup = {
         "properties": {
             "backup": {
                 "type": "object",
-                "required": ["instance", "name"],
+                "required": ["name"],
                 "properties": {
                     "description": non_empty_string,
                     "instance": uuid,
                     "name": non_empty_string,
                     "parent_id": uuid,
                     "incremental": boolean_string,
-                    "swift_container": non_empty_string
+                    "swift_container": non_empty_string,
+                    "restore_from": {
+                        "type": "object",
+                        "required": [
+                            "remote_location",
+                            "local_datastore_version_id",
+                            "size"
+                        ],
+                        "properties": {
+                            "remote_location": non_empty_string,
+                            "local_datastore_version_id": uuid,
+                            "size": {"type": "number"}
+                        }
+                    }
                 }
             }
         }
@@ -820,7 +834,8 @@ configuration = {
                         "additionalProperties": True,
                         "properties": {
                             "type": non_empty_string,
-                            "version": non_empty_string
+                            "version": non_empty_string,
+                            "version_number": non_empty_string
                         }
                     }
                 }
@@ -947,6 +962,19 @@ package_list = {
     }
 }
 
+image_tags = {
+    "type": "array",
+    "minItems": 0,
+    "maxItems": 5,
+    "uniqueItems": True,
+    "items": {
+        "type": "string",
+        "minLength": 1,
+        "maxLength": 20,
+        "pattern": "^.*[0-9a-zA-Z]+.*$"
+    }
+}
+
 mgmt_datastore_version = {
     "create": {
         "name": "mgmt_datastore_version:create",
@@ -955,16 +983,19 @@ mgmt_datastore_version = {
         "properties": {
             "version": {
                 "type": "object",
-                "required": ["name", "datastore_name", "image", "active"],
-                "additionalProperties": True,
+                "required": ["name", "datastore_name", "datastore_manager",
+                             "active"],
+                "additionalProperties": False,
                 "properties": {
                     "name": non_empty_string,
                     "datastore_name": non_empty_string,
                     "datastore_manager": non_empty_string,
                     "packages": package_list,
                     "image": uuid,
+                    "image_tags": image_tags,
                     "active": {"enum": [True, False]},
-                    "default": {"enum": [True, False]}
+                    "default": {"enum": [True, False]},
+                    "version": non_empty_string
                 }
             }
         }
@@ -973,13 +1004,15 @@ mgmt_datastore_version = {
         "name": "mgmt_datastore_version:edit",
         "type": "object",
         "required": [],
-        "additionalProperties": True,
+        "additionalProperties": False,
         "properties": {
             "datastore_manager": non_empty_string,
             "packages": package_list,
             "image": uuid,
+            "image_tags": image_tags,
             "active": {"enum": [True, False]},
             "default": {"enum": [True, False]},
+            "name": non_empty_string
         }
     }
 }
