@@ -23,9 +23,9 @@ from oslo_config import cfg
 from oslo_config import types
 from oslo_config.cfg import NoSuchOptError
 from oslo_log import log as logging
+from oslo_log import versionutils
 from oslo_middleware import cors
 from osprofiler import opts as profiler
-from oslo_log import versionutils
 
 from trove.common.i18n import _
 from trove.version import version_info as version
@@ -245,7 +245,7 @@ common_opts = [
     cfg.IntOpt('trove_conductor_workers',
                help='Number of workers for the Conductor service. The default '
                'will be the number of CPUs available.'),
-    cfg.BoolOpt('use_nova_server_config_drive', default=True,
+    cfg.BoolOpt('use_nova_server_config_drive', default=False,
                 help='Use config drive for file injection when booting '
                 'instance.'),
     cfg.StrOpt('device_path', default='/dev/vdb',
