@@ -17,7 +17,6 @@ from sqlalchemy.schema import Column
 from sqlalchemy.schema import MetaData
 
 from trove.db.sqlalchemy.migrate_repo.schema import create_tables
-from trove.db.sqlalchemy.migrate_repo.schema import drop_tables
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
 
@@ -35,8 +34,3 @@ service_images = Table(
 def upgrade(migrate_engine):
     meta.bind = migrate_engine
     create_tables([service_images])
-
-
-def downgrade(migrate_engine):
-    meta.bind = migrate_engine
-    drop_tables([service_images])
