@@ -16,7 +16,6 @@ from sqlalchemy.schema import Column
 from sqlalchemy.schema import MetaData
 
 from trove.db.sqlalchemy.migrate_repo.schema import create_tables
-from trove.db.sqlalchemy.migrate_repo.schema import drop_tables
 from trove.db.sqlalchemy.migrate_repo.schema import Float
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
@@ -34,8 +33,3 @@ conductor_lastseen = Table(
 def upgrade(migrate_engine):
     meta.bind = migrate_engine
     create_tables([conductor_lastseen])
-
-
-def downgrade(migrate_engine):
-    meta.bind = migrate_engine
-    drop_tables([conductor_lastseen])
