@@ -18,7 +18,6 @@ from sqlalchemy.schema import MetaData
 
 from trove.db.sqlalchemy.migrate_repo.schema import String
 from trove.db.sqlalchemy.migrate_repo.schema import Table
-from trove.db.sqlalchemy import utils as db_utils
 
 
 def upgrade(migrate_engine):
@@ -29,21 +28,3 @@ def upgrade(migrate_engine):
     datastore_version_id = Column('datastore_version_id', String(36),
                                   ForeignKey('datastore_versions.id'))
     backups.create_column(datastore_version_id)
-
-
-def downgrade(migrate_engine):
-    meta = MetaData()
-    meta.bind = migrate_engine
-    backups = Table('backups', meta, autoload=True)
-    datastore_versions = Table('datastore_versions', meta, autoload=True)
-    constraint_names = db_utils.get_foreign_key_constraint_names(
-        engine=migrate_engine,
-        table='backups',
-        columns=['datastore_version_id'],
-        ref_table='datastore_versions',
-        ref_columns=['id'])
-    db_utils.drop_foreign_key_constraints(
-        constraint_names=constraint_names,
-        columns=[backups.c.datastore_version_id],
-        ref_columns=[datastore_versions.c.id])
-    backups.drop_column('datastore_version_id')
