@@ -79,7 +79,7 @@ class MySqlManager(manager.Manager):
 
         # Prepare mysql configuration
         LOG.info('Preparing database configuration')
-        self.app.configuration_manager.save_configuration(config_contents)
+        self.app.configuration_manager.reset_configuration(config_contents)
         self.app.update_overrides(overrides)
 
         # Restore data from backup and reset root password
@@ -112,8 +112,10 @@ class MySqlManager(manager.Manager):
         """
         LOG.info(f"Creating backup {backup_info['id']}")
         with EndNotification(context):
+            # Set /var/run/mysqld to allow localhost access.
             volumes_mapping = {
                 '/var/lib/mysql': {'bind': '/var/lib/mysql', 'mode': 'rw'},
+                "/var/run/mysqld": {"bind": "/var/run/mysqld", "mode": "ro"},
                 '/tmp': {'bind': '/tmp', 'mode': 'rw'}
             }
             self.app.create_backup(context, backup_info,
@@ -171,11 +173,14 @@ class MySqlManager(manager.Manager):
 
     def is_log_enabled(self, logname):
         if logname == self.GUEST_LOG_DEFS_GENERAL_LABEL:
-            value = self.configuration_manager.get_value('general_log', 'off')
+            value = self.configuration_manager.get_value(
+                'general_log', section='mysqld', default='off')
+            LOG.debug(f"The config value of general_log is {value}")
             return value == 'on'
         elif logname == self.GUEST_LOG_DEFS_SLOW_QUERY_LABEL:
-            value = self.configuration_manager.get_value('slow_query_log',
-                                                         'off')
+            value = self.configuration_manager.get_value(
+                'slow_query_log', section='mysqld', default='off')
+            LOG.debug(f"The config value of slow_query_log is {value}")
             return value == 'on'
 
         return False
@@ -308,7 +313,7 @@ class MySqlManager(manager.Manager):
         try:
             # Prepare mysql configuration
             LOG.debug('Preparing database configuration')
-            self.app.configuration_manager.save_configuration(config_contents)
+            self.app.configuration_manager.reset_configuration(config_contents)
             self.app.update_overrides(config_overrides)
 
             # Start database service.
