@@ -378,7 +378,8 @@ class BaseDbApp(object):
         self.configuration_manager.remove_user_override()
 
     def reset_configuration(self, configuration):
-        pass
+        LOG.info("Resetting configuration.")
+        self.configuration_manager.reset_configuration(configuration)
 
     def stop_db(self, update_db=False):
         LOG.info("Stopping database.")
@@ -395,7 +396,14 @@ class BaseDbApp(object):
         ):
             raise exception.TroveError("Failed to stop database")
 
+    def start_db(self, *args, **kwargs):
+        pass
+
     def start_db_with_conf_changes(self, config_contents, ds_version):
+        """Start the database with given configuration.
+
+        This method is called after resize.
+        """
         LOG.info(f"Starting database service with new configuration and "
                  f"datastore version {ds_version}.")
 
@@ -435,7 +443,8 @@ class BaseDbApp(object):
         db_userinfo = ''
         if need_dbuser:
             admin_pass = self.get_auth_password()
-            db_userinfo = (f"--db-host=127.0.0.1 --db-user=os_admin "
+            # Use localhost to avoid host access verification.
+            db_userinfo = (f"--db-host=localhost --db-user=os_admin "
                            f"--db-password={admin_pass}")
 
         swift_metadata = (
@@ -500,7 +509,16 @@ class BaseDbApp(object):
                     'success': False,
                     'state': BackupState.FAILED,
                 })
-                raise Exception(msg)
+
+                # The exception message is visible to the user
+                user_msg = msg
+                ex_regex = re.compile(r'.+Exception: (.+)')
+                for line in output[-5:-1]:
+                    m = ex_regex.search(line)
+                    if m:
+                        user_msg = m.group(1)
+                        break
+                raise Exception(user_msg)
         except Exception as err:
             LOG.error("Failed to create backup %s", backup_id)
             backup_state.update({
