@@ -56,9 +56,14 @@ def start_container(client, image, name="database",
     """
     try:
         container = client.containers.get(name)
+        LOG.info(f'Starting existing container {name}')
         container.start()
     except docker.errors.NotFound:
-        LOG.warning("Failed to get container %s", name)
+        LOG.info(
+            f"Creating docker container, image: {image}, "
+            f"volumes: {volumes}, ports: {ports}, user: {user}, "
+            f"network_mode: {network_mode}, environment: {environment}, "
+            f"command: {command}")
         container = client.containers.run(
             image,
             name=name,
@@ -91,11 +96,16 @@ def run_container(client, image, name, network_mode="host", volumes={},
     """
     try:
         container = client.containers.get(name)
+        LOG.debug(f'Removing existing container {name}')
         container.remove(force=True)
     except docker.errors.NotFound:
         pass
 
     try:
+        LOG.info(
+            f'Running container {name}, image: {image}, '
+            f'network_mode: {network_mode}, volumes: {volumes}, '
+            f'command: {command}')
         output = client.containers.run(
             image,
             name=name,
