@@ -19,7 +19,6 @@ from proboscis.asserts import assert_raises
 from proboscis.asserts import assert_true
 from proboscis import before_class
 from proboscis import test
-import six
 from troveclient.compat import exceptions
 
 from trove import tests
@@ -48,8 +47,8 @@ class Datastores(object):
         datastores = self.rd_client.datastores.list()
         for datastore in datastores:
             with TypeCheck('Datastore', datastore) as check:
-                check.has_field("id", six.string_types)
-                check.has_field("name", six.string_types)
+                check.has_field("id", str)
+                check.has_field("name", str)
                 check.has_field("links", list)
                 check.has_field("versions", list)
 
@@ -59,8 +58,8 @@ class Datastores(object):
         datastore_by_name = self.rd_client.datastores.get(
             test_config.dbaas_datastore)
         with TypeCheck('Datastore', datastore_by_name) as check:
-            check.has_field("id", six.string_types)
-            check.has_field("name", six.string_types)
+            check.has_field("id", str)
+            check.has_field("name", str)
             check.has_field("links", list)
         assert_equal(datastore_by_name.name, test_config.dbaas_datastore)
 
@@ -68,8 +67,8 @@ class Datastores(object):
         datastore_by_id = self.rd_client.datastores.get(
             datastore_by_name.id)
         with TypeCheck('Datastore', datastore_by_id) as check:
-            check.has_field("id", six.string_types)
-            check.has_field("name", six.string_types)
+            check.has_field("id", str)
+            check.has_field("name", str)
             check.has_field("links", list)
             check.has_field("versions", list)
         assert_equal(datastore_by_id.id, datastore_by_name.id)
@@ -85,25 +84,19 @@ class Datastores(object):
 
     @test
     def test_create_inactive_datastore_by_admin(self):
-        datastores = self.rd_client.datastores.list()
+        datastores = self.rd_admin.datastores.list()
         for ds in datastores:
             if ds.name == test_config.dbaas_datastore_name_no_versions:
                 for version in ds.versions:
                     if version['name'] == 'inactive_version':
                         return
 
-        # Get a valid image ID from a datastore version
-        datastore = self.rd_client.datastores.get(test_config.dbaas_datastore)
-        ds_version = self.rd_client.datastore_versions.list(datastore.id)[0]
-        ds_version_info = self.rd_admin.datastore_versions.get_by_uuid(
-            ds_version.id)
-
         # Create datastore version for testing
         # 'Test_Datastore_1' is also used in other test cases.
         # Will be deleted in test_delete_datastore_version
         self.rd_admin.mgmt_datastore_versions.create(
             "inactive_version", test_config.dbaas_datastore_name_no_versions,
-            "test_manager", ds_version_info.image,
+            "test_manager", None, image_tags=['trove'],
             active='false', default='false'
         )
 
@@ -140,8 +133,8 @@ class DatastoreVersions(object):
             self.datastore_active.name)
         for version in versions:
             with TypeCheck('DatastoreVersion', version) as check:
-                check.has_field("id", six.string_types)
-                check.has_field("name", six.string_types)
+                check.has_field("id", str)
+                check.has_field("name", str)
                 check.has_field("links", list)
 
     @test
@@ -149,9 +142,9 @@ class DatastoreVersions(object):
         version = self.rd_client.datastore_versions.get(
             self.datastore_active.name, self.datastore_version_active.name)
         with TypeCheck('DatastoreVersion', version) as check:
-            check.has_field("id", six.string_types)
-            check.has_field("name", six.string_types)
-            check.has_field("datastore", six.string_types)
+            check.has_field("id", str)
+            check.has_field("name", str)
+            check.has_field("datastore", str)
             check.has_field("links", list)
         assert_equal(version.name, self.datastore_version_active.name)
 
@@ -160,21 +153,17 @@ class DatastoreVersions(object):
         version = self.rd_client.datastore_versions.get_by_uuid(
             self.datastore_version_active.id)
         with TypeCheck('DatastoreVersion', version) as check:
-            check.has_field("id", six.string_types)
-            check.has_field("name", six.string_types)
-            check.has_field("datastore", six.string_types)
+            check.has_field("id", str)
+            check.has_field("name", str)
+            check.has_field("datastore", str)
             check.has_field("links", list)
         assert_equal(version.name, self.datastore_version_active.name)
 
     @test
     def test_datastore_version_not_found(self):
-        try:
-            assert_raises(exceptions.NotFound,
-                          self.rd_client.datastore_versions.get,
-                          self.datastore_active.name, NAME)
-        except exceptions.BadRequest as e:
-            assert_equal(e.message,
-                         "Datastore version '%s' cannot be found." % NAME)
+        assert_raises(exceptions.BadRequest,
+                      self.rd_client.datastore_versions.get,
+                      self.datastore_active.name, NAME)
 
     @test
     def test_datastore_version_list_by_uuid(self):
@@ -182,8 +171,8 @@ class DatastoreVersions(object):
             self.datastore_active.id)
         for version in versions:
             with TypeCheck('DatastoreVersion', version) as check:
-                check.has_field("id", six.string_types)
-                check.has_field("name", six.string_types)
+                check.has_field("id", str)
+                check.has_field("name", str)
                 check.has_field("links", list)
 
     @test
@@ -191,9 +180,9 @@ class DatastoreVersions(object):
         version = self.rd_client.datastore_versions.get(
             self.datastore_active.id, self.datastore_version_active.id)
         with TypeCheck('DatastoreVersion', version) as check:
-            check.has_field("id", six.string_types)
-            check.has_field("name", six.string_types)
-            check.has_field("datastore", six.string_types)
+            check.has_field("id", str)
+            check.has_field("name", str)
+            check.has_field("datastore", str)
             check.has_field("links", list)
         assert_equal(version.name, self.datastore_version_active.name)
 
