@@ -16,7 +16,6 @@
 from datetime import datetime
 import json
 from proboscis import SkipTest
-import six
 
 from trove.common.utils import generate_uuid
 from trove.tests.scenario.runners.test_runners import TestRunner
@@ -140,12 +139,12 @@ class ConfigurationRunner(TestRunner):
         self.assert_client_code(client, expected_http_code)
 
         with TypeCheck('Configuration', result) as configuration:
-            configuration.has_field('name', six.string_types)
-            configuration.has_field('description', six.string_types)
+            configuration.has_field('name', str)
+            configuration.has_field('description', str)
             configuration.has_field('values', dict)
-            configuration.has_field('datastore_name', six.string_types)
-            configuration.has_field('datastore_version_id', six.text_type)
-            configuration.has_field('datastore_version_name', six.string_types)
+            configuration.has_field('datastore_name', str)
+            configuration.has_field('datastore_version_id', str)
+            configuration.has_field('datastore_version_name', str)
 
             self.assert_equal(name, result.name)
             self.assert_equal(description, result.description)
@@ -217,12 +216,12 @@ class ConfigurationRunner(TestRunner):
 
         # check the result field types
         with TypeCheck("configuration", result) as check:
-            check.has_field("id", six.string_types)
-            check.has_field("name", six.string_types)
-            check.has_field("description", six.string_types)
+            check.has_field("id", str)
+            check.has_field("name", str)
+            check.has_field("description", str)
             check.has_field("values", dict)
-            check.has_field("created", six.string_types)
-            check.has_field("updated", six.string_types)
+            check.has_field("created", str)
+            check.has_field("updated", str)
             check.has_field("instance_count", int)
 
         # check for valid timestamps
@@ -244,7 +243,7 @@ class ConfigurationRunner(TestRunner):
                 if param.type == 'integer':
                     check.has_element(item_key, int)
                 if param.type == 'string':
-                    check.has_element(item_key, six.string_types)
+                    check.has_element(item_key, str)
                 if param.type == 'boolean':
                     check.has_element(item_key, bool)
 
