@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from mock import Mock
+from unittest.mock import Mock
 import webob
 
 from trove.common import cfg
