@@ -13,9 +13,9 @@
 
 import jsonschema
 
-from mock import MagicMock
-from mock import Mock
-from mock import patch
+from unittest.mock import MagicMock
+from unittest.mock import Mock
+from unittest.mock import patch
 from testtools.matchers import Is, Equals
 from trove.cluster import models
 from trove.cluster.models import Cluster
@@ -74,7 +74,7 @@ class TestClusterController(trove_testtools.TestCase):
         schema = self.controller.get_schema('create', self.cluster)
         self.assertIsNotNone(schema)
         self.assertIn('cluster', schema['properties'])
-        self.assertTrue('cluster')
+        self.assertIsNotNone(schema['properties']['cluster'])
 
     def test_validate_create(self):
         body = self.cluster
