@@ -23,7 +23,6 @@ from proboscis.asserts import assert_not_equal
 from proboscis.asserts import assert_true
 from proboscis.asserts import ASSERTION_ERROR
 from proboscis.asserts import Check
-import six
 
 
 def get_stack_trace_of_caller(level_up):
@@ -40,7 +39,7 @@ def get_stack_trace_of_caller(level_up):
 def raise_blame_caller(level_up, ex):
     """Raises an exception, changing the stack trace to point to the caller."""
     new_st = get_stack_trace_of_caller(level_up + 2)
-    six.reraise(type(ex), ex, new_st)
+    raise ex.with_traceback(new_st)
 
 
 class Checker(object):
